SELECT
    1 AS payer_plan_period_id,
    1 AS person_id,
    now()::DATE AS payer_plan_period_start_date,
    now()::DATE AS payer_plan_period_end_date,
    0 AS payer_concept_id,
    '' AS payer_source_value,
    0 AS payer_source_concept_id,
    0 AS plan_concept_id,
    '' AS plan_source_value,
    0 AS plan_source_concept_id,
    0 AS sponsor_concept_id,
    '' AS sponsor_source_value,
    0 AS sponsor_source_concept_id,
    '' AS family_source_value,
    0 AS stop_reason_concept_id,
    '' AS stop_reason_source_value,
    0 AS stop_reason_source_concept_id
