SELECT
    1 AS note_nlp_id,
    1 AS note_id,
    0 AS section_concept_id,
    '' AS snippet,
    '' AS "offset",
    '' AS lexical_variant,
    0 AS note_nlp_concept_id,
    0 AS note_nlp_source_concept_id,
    '' AS nlp_system,
    now()::DATE AS nlp_date,
    now()::TIMESTAMP AS nlp_datetime,
    '' AS term_exists,
    '' AS term_temporal,
    '' AS term_modifiers
