SELECT
    1 AS cost_id,
    1 AS cost_event_id,
    'Cost' AS cost_domain_id,
    0 AS cost_type_concept_id,
    0 AS currency_concept_id,
    1.0 AS total_charge,
    1.0 AS total_cost,
    1.0 AS total_paid,
    1.0 AS paid_by_payer,
    1.0 AS paid_by_patient,
    1.0 AS paid_patient_copay,
    1.0 AS paid_patient_coinsurance,
    1.0 AS paid_patient_deductible,
    1.0 AS paid_by_primary,
    1.0 AS paid_ingredient_cost,
    1.0 AS paid_dispensing_fee,
    1 AS payer_plan_period_id,
    1.0 AS amount_allowed,
    0 AS revenue_code_concept_id,
    '' AS revenue_code_source_value,
    0 AS drg_concept_id,
    '' AS drg_source_value
