SELECT
    1 AS person_id,
    1 AS visit_detail_id,
    0 AS visit_detail_concept_id,
    0 AS visit_detail_type_concept_id,
    1 AS provider_id,
    1 AS care_site_id,
    '' AS visit_detail_source_value,
    0 AS visit_detail_source_concept_id,
    '' AS admitted_from_source_value,
    0 AS admitted_from_concept_id,
    '' AS discharged_to_source_value,
    0 AS discharged_to_concept_id,
    1 AS visit_occurrence_id,
    now()::DATE AS visit_detail_start_date,
    now()::TIMESTAMP AS visit_detail_start_datetime,
    now()::DATE AS visit_detail_end_date,
    now()::TIMESTAMP AS visit_detail_end_datetime,
    NULL::int AS parent_visit_detail_id,
    NULL::int AS preceding_visit_detail_id
