SELECT
    1 AS location_id,
    '' AS address_1,
    '' AS address_2,
    '' AS city,
    '' AS state,
    '' AS zip,
    '' AS county,
    '' AS location_source_value,
    0 AS country_concept_id,
    '' AS country_source_value,
    1.0 AS latitude,
    1.0 AS longitude
