SELECT
    1 AS device_exposure_id,
    1 AS person_id,
    0 AS device_concept_id,
    now()::DATE AS device_exposure_start_date,
    now()::TIMESTAMP AS device_exposure_start_datetime,
    now()::DATE AS device_exposure_end_date,
    now()::TIMESTAMP AS device_exposure_end_datetime,
    0 AS device_type_concept_id,
    '' AS unique_device_id,
    '' AS production_id,
    1 AS quantity,
    1 AS provider_id,
    1 AS visit_occurrence_id,
    1 AS visit_detail_id,
    '' AS device_source_value,
    0 AS device_source_concept_id,
    0 AS unit_concept_id,
    '' AS unit_source_value,
    0 AS unit_source_concept_id
