COPY {{ schema }}.CONCEPT FROM '/vocabulary/CONCEPT.csv' WITH (FORMAT csv, HEADER true, DELIMITER E'\t', QUOTE E'\b');
COPY {{ schema }}.CONCEPT_ANCESTOR FROM '/vocabulary/CONCEPT_ANCESTOR.csv' WITH (FORMAT csv, HEADER true, DELIMITER E'\t', QUOTE E'\b');
COPY {{ schema }}.CONCEPT_CLASS FROM '/vocabulary/CONCEPT_CLASS.csv' WITH (FORMAT csv, HEADER true, DELIMITER E'\t', QUOTE E'\b');
COPY {{ schema }}.CONCEPT_RELATIONSHIP FROM '/vocabulary/CONCEPT_RELATIONSHIP.csv' WITH (FORMAT csv, HEADER true, DELIMITER E'\t', QUOTE E'\b');
COPY {{ schema }}.CONCEPT_SYNONYM FROM '/vocabulary/CONCEPT_SYNONYM.csv' WITH (FORMAT csv, HEADER true, DELIMITER E'\t', QUOTE E'\b');
COPY {{ schema }}.DOMAIN FROM '/vocabulary/DOMAIN.csv' WITH (FORMAT csv, HEADER true, DELIMITER E'\t', QUOTE E'\b');
COPY {{ schema }}.DRUG_STRENGTH FROM '/vocabulary/DRUG_STRENGTH.csv' WITH (FORMAT csv, HEADER true, DELIMITER E'\t', QUOTE E'\b');
COPY {{ schema }}.RELATIONSHIP FROM '/vocabulary/RELATIONSHIP.csv' WITH (FORMAT csv, HEADER true, DELIMITER E'\t', QUOTE E'\b');
COPY {{ schema }}.VOCABULARY FROM '/vocabulary/VOCABULARY.csv' WITH (FORMAT csv, HEADER true, DELIMITER E'\t', QUOTE E'\b');
