SELECT
    '' AS cdm_source_name,
    '' AS cdm_source_abbreviation,
    '' AS cdm_holder,
    '' AS source_description,
    '' AS source_documentation_reference,
    '' AS cdm_etl_reference,
    now()::DATE AS source_release_date,
    now()::DATE AS cdm_release_date,
    '' AS cdm_version,
    0 AS cdm_version_concept_id,
    '' AS vocabulary_version
