SELECT
    1 AS measurement_id,
    1 AS person_id,
    0 AS measurement_concept_id,
    now()::DATE AS measurement_date,
    now()::TIMESTAMP AS measurement_datetime,
    '' AS measurement_time,
    0 AS measurement_type_concept_id,
    0 AS operator_concept_id,
    1.0 AS value_as_number,
    0 AS value_as_concept_id,
    0 AS unit_concept_id,
    1.0 AS range_low,
    1.0 AS range_high,
    1 AS provider_id,
    1 AS visit_occurrence_id,
    1 AS visit_detail_id,
    '' AS measurement_source_value,
    0 AS measurement_source_concept_id,
    '' AS unit_source_value,
    0 AS unit_source_concept_id,
    '' AS value_source_value,
    1::BIGINT AS measurement_event_id,
    0 AS meas_event_field_concept_id
