SELECT
    1 AS observation_id,
    1 AS person_id,
    0 AS observation_concept_id,
    now()::DATE AS observation_date,
    now()::TIMESTAMP AS observation_datetime,
    0 AS observation_type_concept_id,
    1.0 AS value_as_number,
    '' AS value_as_string,
    0 AS value_as_concept_id,
    0 AS qualifier_concept_id,
    0 AS unit_concept_id,
    1 AS provider_id,
    1 AS visit_occurrence_id,
    1 AS visit_detail_id,
    '' AS observation_source_value,
    0 AS observation_source_concept_id,
    '' AS unit_source_value,
    '' AS qualifier_source_value,
    '' AS value_source_value,
    1::BIGINT AS observation_event_id,
    0 AS obs_event_field_concept_id
