SELECT
    1 AS person_id,
    0 AS race_concept_id,
    '' AS race_source_value,
    0 AS race_source_concept_id,
    '' AS ethnicity_source_value,
    0 AS ethnicity_concept_id,
    0 AS ethnicity_source_concept_id,
    1 AS care_site_id,
    1 AS provider_id,
    1 AS location_id,
    '' AS person_source_value,
    0 AS gender_source_concept_id,
    '' AS gender_source_value,
    now()::TIMESTAMP AS birth_datetime,
    0 AS gender_concept_id,
    to_char(now(), 'YYYY')::int AS year_of_birth,
    to_char(now(), 'MM')::int AS month_of_birth,
    to_char(now(), 'DD')::int AS day_of_birth
